@@ -17,7 +17,7 @@ def uncompress(zip_file_path, password):
 
 
 def delete_unzipped_file(unzip_file_path):
-    # os.remove(unzip_file_path)
+    os.remove(unzip_file_path)
     return
 
 
